pub struct Region {
pub records: Vec<Record>,
}Expand description
A container for one or several Crash Log records.
A Crash Log region refers to a region in an on-die memory that is allocated for storing a contiguous sequence of Crash Log records.
Fields
records: Vec<Record>Implementations